DynamicInsertResult class

Result of a dynamic-label node insert: the new node's RecordId plus a JSON object string mapping each label name to {"id":<u16>,"created":<bool>}.

Constructors

DynamicInsertResult({required RecordId rid, required String assignmentsJson})
const

Properties

assignmentsJson String
final
hashCode int
The hash code for this object.
no setteroverride
rid RecordId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override